% This code plots supply and demand functions
% it computes the market allocation with  fund of a given size
% to obtain the market allocation set the size F of the fund to 0, line 48
% it also computes the size of the fund for full risk-sharing



clc;clear all;
close all;



disp('Computing the market equilibrium');
%parameters_haircut;
lambda  = .15;
sigma   = 2.00;
beta    = 0.96;
delta   = 0.985;%0.99;%0.986;%0.7
alpha   = 0.965; % from hamilton Quarterly value 0.9
Bbar    = -0.03; % must be NEGATIVE. Amount of debt recovered.
rho     = 0.87;% Quarterly value 0.75

%ZD = 0.9942;%0.95; %labor productivity is ZD$L (instead of l) after default
ZD = 0.998;%0.95; %labor productivity is ZD$L (instead of l) after default

u = @(c) c.^(1-sigma)/(1-sigma) - 1/(1-sigma) ; %u = @(c) log(c);%cas log sigma=1
up = @(c) c.^(-sigma) ;
upinv = @(c) c.^(-1/sigma) ;

RR = [alpha,1-rho;1-alpha,rho];
ne = (1-rho)/(2-alpha-rho); % share of productive


Dv      = [2:1:19];%[5:1:12]
betai   = 0.960001;
betaf   = 0.9605;
Ninc    = 100;%1000

GG      = 0.001; %relaxation parameter for the iteration over p


pv      = [betai:(betaf-betai)/Ninc:betaf];
res     = zeros(length(pv),length(Dv)*3);


%%%%% HERE Size of the fund : external liquidity

%F = 0.09; % size of the fund (it is a debt : positive sign)
F = 0.00; % size of the fund (it is a debt : positive sign)

for iD = 1:length(Dv)

        D = Dv(iD); % number of periods before default

        np0 = ne*lambda/(lambda +(1-lambda)*(1-alpha)*rho^(D-1)); % share of productive participating


        for k=1:D
            np(k) = (1-alpha)*np0*rho^(k-1);
        end;

        npartot = np0 + sum(np(1:D-1)); % size participating
     
        nextot = 1-npartot;

        % Average exclusion period

        T  = [alpha, (1-rho);1-alpha,rho];
        Tt = [alpha*(1-lambda), (1-rho)*(1-lambda);1-alpha,rho];

        MM = zeros(2);
        NN = zeros(2);
        LL = 1000;
        for k=1:LL;
            MM = MM + k*Tt^(k-1);
            NN = NN + Tt^(k-1);
        end;

        Texcl = [lambda,0]*T*MM*[0;1] + ...
            (LL+1)*(1-[lambda,0]*T*NN*[0;1]);

        % probability of default (% fraction of default per period)
        Frac = np(D); % because agents defaut lafter D periods of being unproductive
        fprintf('Iterating on prices for D =   %1i  \n',D);

       Delta = 1;
        for i=1:length(pv)

                    p = pv(i);
                    tau = F*(1-p)/npartot;
                %while abs(Delta)>10^-7 % loop of prices

                c(1) = upinv( (p/beta-alpha)/(1-alpha));

                for k = 1:(D-2)
                    c(k+1) = upinv(  (p*up(c(k))/beta-(1-rho))/rho );
                end;

                pt = beta/up(c(D-1));


                % 3)  I set a value for W0
                W0 = -25;

                 dist = 1;
                 while abs(dist)>10^-6 %loop on W0

                        % Autarky (different from value of defaut because of the haircut)
                        twist = 1; % set to 0 for robots
                        N = [ rho, (1-rho)*(1-twist*lambda);(1-alpha),alpha*(1-twist*lambda)];
                        Vect = [u(ZD*delta)-delta+beta*twist*lambda*(1-rho)*W0; u(upinv(1/ZD))-upinv(1/ZD)/ZD+beta*twist*lambda*alpha*W0];
                        A = ((eye(2) - beta*N)^-1)*Vect;
                        Vuaut0 = A(1);
                        Veaut0 = A(2);

                        %value in default
                        Vuaut = u(ZD*delta + Bbar)- delta                  + beta*(1-rho)*(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*rho*Vuaut0;
                        Veaut = u(upinv(1/ZD))    -(upinv(1/ZD) - Bbar)/ZD + beta*alpha  *(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*(1-alpha)*Vuaut0;

                        % default in 2

                        %a(D-1) = ((1-beta*rho)*Vuaut - u(c(D-1)) + delta - + beta*(1-rho)*W0)/(beta*(1-rho));
                        aeb = Veaut-W0;
                        a(D-1) = aeb;

                        if D>2
                            a(D-2) = p*(1-rho)*a(D-1)+c(D-1)-delta+ tau + p*rho*Bbar;   %TAU
                                for k=(D-2):-1:2;
                                    a(k-1) = p*a(k)+c(k)-delta +tau;
                                end;
                                a0 = p*a(1)+c(1)-delta +tau;
                        else
                            a0 = p*(1-rho)*a(1)+c(1)-delta +tau;

                        end
                        % 4) I solve for W0
                        Vu(D) = Vuaut;
                        for k=(D-1):-1:1;
                            Vu(k) = u(c(k))-delta +beta*(1-rho)*a(k)+beta*(1-rho)*W0...
                                +beta*rho*Vu(k+1);
                        end;

                        W0t = (u(upinv(1))-upinv(1) -p*a0 +beta*alpha*a0+beta*(1-alpha)*Vu(1))/(1-beta*alpha);
                        dist = W0-W0t;
                        W0 = W0 -0.1*dist;
                        %dist = 0;
                         end;
                         
                 %Delta has to converge to 0 (Financial market equilibrium)

                apos = max(a,0);
                aneg = min(a,0);

                Deltapos    = np0*max(a0,0) + np(1:(D-2))*apos(1:D-2)' + np(D-1)*(1-rho)*apos(D-1) ;
                Deltaneg    = - (np0*min(a0,0)+np(1:(D-2))*aneg(1:D-2)' + np(D-1)*(1-rho)*aneg(D-1) + np(D-1)*rho*Bbar) +F;
                Delta2      = Deltapos - Deltaneg;
                %Delta       = np0*a0 + np(1:(D-2))*a(1:D-2)' + np(D-1)*(1-rho)*a(D-1) + np(D-1)*rho*Bbar;
               
                %%%%  Checking that a is decreasing
                av = [a0,a];
                avs = sort(av,'descend');
                inc_index = false;
                if avs == av
                    inc_index =true; % decreasing saving : condition for existence
                end;
              
                   res(i,1+(iD-1)*3) = inc_index*W0 + (inc_index-1)*1000;                  
                   res(i,2+(iD-1)*3) = Deltapos;
                   res(i,3+(iD-1)*3) = Deltaneg;
                   exist(i,iD) = inc_index;
        end;
        
     

end


%%%%%%%%%%%%%%%%%%%%%%%%%% Ploting supply and demand functions

clear Su De
LL      = size(res,2)/3;
for i=1:length(pv)
    for j = 1:LL
        W0v(j)  = res(i,1+(j-1)*3);
    end;
    [Val,ind]  = max(W0v);
    W0max(i)   = Val;
    Dmax (i)   = (ind-1) +Dv(1);
    Su(i)      = res(i,1+(ind-1)*3+1);
    De(i)      = res(i,1+(ind-1)*3+2);
    Eq(i)      = exist(ind,j);
end;

figure(1)
plot(pv,De,'-b'); 
hold on;
plot(pv,Su,'.-.r'); 

%Dopt = Dmax(max(find((Su-De)>0)));
%peq =  pv(max(find((Su-De)>0)));

Dopt = Dmax(min(find((Su-De)<0)));
peq  = pv(min(find((Su-De)<0)));

hold on 
%plot(pv,Dmax/1000,'.-.k'); 
%title('Financial market equilibrium');




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% I redo everything for optimal values
%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



clear c a Vu
D = Dopt;

np0 = ne*lambda/(lambda +(1-lambda)*(1-alpha)*rho^(D-1)); % share of productive participating

for k=1:D
    np(k) = (1-alpha)*np0*rho^(k-1);
end;

npartot = np0 + sum(np(1:D-1)); % size participating
nextot = 1-npartot;

% Average exclusion period
T  = [alpha, (1-rho);1-alpha,rho];
Tt = [alpha*(1-lambda), (1-rho)*(1-lambda);1-alpha,rho];

MM = zeros(2);
NN = zeros(2);
LL = 1000;
for k=1:LL;
    MM = MM + k*Tt^(k-1);
    NN = NN + Tt^(k-1);
end;

Texcl = [lambda,0]*T*MM*[0;1] + ...
    (LL+1)*(1-[lambda,0]*T*NN*[0;1]);

% probability of default (% fraction of default per period)
Frac = np(D); % because agents defaut lafter D periods of being unproductive
Delta = 1;
p = peq;
c(1) = upinv( (p/beta-alpha)/(1-alpha));

for k = 1:(D-2)
    c(k+1) = upinv(  (p*up(c(k))/beta-(1-rho))/rho );
end;

 tau = F*(1-p)/npartot;

pt = beta/up(c(D-1));


% 3)  I set a value for W0
W0 = -25;
dist = 1;
 while abs(dist)>10^-6 %loop on W0

        % Autarky (different from value of defaut because of the haircut)
        twist = 1; % set to 0 for robots
        N = [ rho, (1-rho)*(1-twist*lambda);(1-alpha),alpha*(1-twist*lambda)];
        Vect = [u(ZD*delta)-delta+beta*twist*lambda*(1-rho)*W0; u(upinv(1/ZD))-upinv(1/ZD)/ZD+beta*twist*lambda*alpha*W0];
        A = ((eye(2) - beta*N)^-1)*Vect;
        Vuaut0 = A(1);
        Veaut0 = A(2);

        %value in default
        Vuaut = u(ZD*delta + Bbar)- delta                  + beta*(1-rho)*(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*rho*Vuaut0;
        Veaut = u(upinv(1/ZD))    -(upinv(1/ZD) - Bbar)/ZD + beta*alpha  *(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*(1-alpha)*Vuaut0;

        % default in 2

        %a(D-1) = ((1-beta*rho)*Vuaut - u(c(D-1)) + delta - + beta*(1-rho)*W0)/(beta*(1-rho));
        aeb = Veaut-W0;
        a(D-1) = aeb;

        if D>2
            a(D-2) = p*(1-rho)*a(D-1)+c(D-1)-delta + p*rho*Bbar +tau;
                for k=(D-2):-1:2;
                    a(k-1) = p*a(k)+c(k)-delta +tau;
                end;
                a0 = p*a(1)+c(1)-delta +tau;
        else
            a0 = p*(1-rho)*a(1)+c(1)-delta +tau;

        end

        % 4) I solve for W0

        Vu(D) = Vuaut;

        for k=(D-1):-1:1;
            Vu(k) = u(c(k))-delta +beta*(1-rho)*a(k)+beta*(1-rho)*W0...
                +beta*rho*Vu(k+1);
        end;

        W0t = (u(upinv(1))-upinv(1) -p*a0 +beta*alpha*a0+beta*(1-alpha)*Vu(1))/(1-beta*alpha);
        dist = W0-W0t;
        W0 = W0 -0.1*dist;
        %dist = 0;
         end;


 %Delta has to converge to 0 (Financial market equilibrium)

apos = max(a,0);

aneg = min(a,0);

Deltapos    = np0*max(a0,0) + np(1:(D-2))*apos(1:D-2)' + np(D-1)*(1-rho)*apos(D-1) ;
Deltaneg    = - (np0*min(a0,0)+np(1:(D-2))*aneg(1:D-2)' + np(D-1)*(1-rho)*aneg(D-1) + np(D-1)*rho*Bbar);
Delta2      = Deltapos - Deltaneg;
%Delta       = np0*a0 + np(1:(D-2))*a(1:D-2)' + np(D-1)*(1-rho)*a(D-1) + np(D-1)*rho*Bbar;
     
F2 = Delta2;


AD = A;
pD = p;
aD0 = a0;
aD = a([1:D-1]);
W0D = W0;
VuD = Vu([1:D]);
cD=c;

 

 % Welfare

clear p a0 a W0 vU c
p  =  pD;
a0 = aD0;
a = aD;
W0 = W0D;
Vu = VuD;
c = cD;

nex0 = ne*(1-lambda)*(1-alpha)*(rho^(D-1))/(lambda +(1-lambda)*(1-alpha)*rho^(D-1));% total productive excluded
nex01 = np0*(1-alpha)*rho^D; % countries just defaulting (being unproductive)

for k=1:D-1
    nex(k) = (1-alpha)*nex0*rho^(k-1);
end;


for k=D:1000
    nex(k) = (1-alpha)*(1-rho)/(2-alpha-rho)*(rho^(k-1));
end;


 
 for i =1:D-1;
     l0(i) = p*a0 + upinv(1)-a(i);
 end;   
 
 l00 = p*a0 + upinv(1)-a0 ;
 
 l0expar = p*a0 + upinv(1);
 
 Welfm = np0*u(upinv(1)) - alpha*np0*l00...
     -(1-rho)*(np(1:D-1)*l0(1:D-1)')...
     -lambda*(alpha*nex0+(1-rho)*(nextot-nex0))*l0expar...
     + sum( np(1:D-1).*(u(c(1:D-1))-delta))...
    + nex0*(u(upinv(1/ZD))-upinv(1/ZD)/ZD)...
    + (nextot-nex0 - nex01)*(u(ZD*delta)-delta)...
    + nex01*(u(ZD*delta+Bbar)-delta);
 
 %check
 XX = np0...
     + sum( np(1:D-1))...
     + nex0...
     +(nextot-nex0)...
     -1;
 
WELFARE_M = (1+Welfm)/(1-beta);


Vuautm = Vuaut;
Veautm = Veaut;

save welfare_market_haircut WELFARE_M Welfm Vuautm Veautm Veaut0 Vuaut0
%
figure(2);
plot([aD0,aD]);
title('Savings');

figure(3);
plot([1,c]);
title('Consumption');



%targets (for D=2 only)
DGDP = a(D-1)/delta;
 
 GDP = np0*(upinv(1)) ...
     + sum( np(1:D-1).*((c(1:D-1))))...
    + nex0*((upinv(1/ZD)))...
    + (nextot-nex0 - nex01)*((ZD*delta))...
    + nex01*((ZD*delta+Bbar));


 COND = W0 - Veaut0;

r_int = 1/p;
fprintf('\n');
fprintf('Want to join the fund (must be >0)   %2.5f   \n',COND);
fprintf('Size of the fund  %2.2f percent \n',100*F/GDP);
fprintf('The number of period unproductive before default is  %d  \n',D);
fprintf('Debt over GDP of defaulting countries is %2.2f percent  \n',DGDP*100);
fprintf('The annual world interest rate is %4.6f percent \n',(r_int-1)*100);
fprintf('Haircut rate is %2.2f percent \n',(1-Bbar/a(D-1))*100);
fprintf('The percentage of countries defaulting  is %2.2f percent \n',nex01*100);
fprintf('Share of countries in the default state is %2.2f percent \n',nextot*100);
fprintf('The probability of default is %2.2f percent \n',Frac*100);
fprintf('Welfare (transformed) is %2.2f percent \n',WELFARE_M*100);
fprintf('Contribution to the fund  is %2.2f percent \n',tau*100/GDP);


%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%  Fund Full risk-sharing                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% max   D=26
D = 18;


disp('Computing the Fund-economy')
GG = 0.1; %relaxation parameter for the iteration over p

p = beta; % initial price


np0 = ne*lambda/(lambda +(1-lambda)*(1-alpha)*rho^(D-1)); % share of productive participating
for k=1:D
    np(k) = (1-alpha)*np0*rho^(k-1);
end;


npartot = np0 + sum(np(1:D-1)); % share of participatin (productive and non-productive)
nextot = 1-npartot;


WGDP = (np0+delta*sum(np(1:D-1))) + ZD*((ne-np0)+delta*( (1-ne)-sum(np(1:D-1)))); %World GDP (equal world consumption)
AGDP = (np0+delta*sum(np(1:D-1)))/(np0+sum(np(1:D-1))); % average GDP of countries participating to the fund

nex0 = ne*(1-lambda)*(1-alpha)*(rho^(D-1))/(lambda +(1-lambda)*(1-alpha)*rho^(D-1));
nre = lambda*(alpha*nex0+(1-rho)*(nextot-nex0)); % measure of agents reentering in each period

% Average exclusion period

T  = [alpha, (1-rho);1-alpha,rho];
Tt = [alpha*(1-lambda), (1-rho)*(1-lambda);1-alpha,rho];

MM = zeros(2);
NN = zeros(2);
LL = 1000;
for k=1:LL;
    MM = MM + k*Tt^(k-1);
    NN = NN + Tt^(k-1);
end;

Texcl = [lambda,0]*T*MM*[0;1] + ...
    (LL+1)*(1-[lambda,0]*T*NN*[0;1]);

% probability of default (% fraction of default per period)
Frac = np(D); % because agents defaut lafter D periods of being unproductive

F = 0.;



disp('Starting solving ');

Delta = 1;
while abs(Delta)>10^-6

tau = F*(1-p)/npartot;
    
c(1) = upinv( (p/beta-alpha)/(1-alpha));

for k = 1:(D-2)
    c(k+1) = upinv(  (p*up(c(k))/beta-(1-rho))/rho );
end;

pt = beta/up(c(D-1));


% 3)  I set a value for W0
W0 = -25;
dist = 1;
 while abs(dist)>10^-6 %loop on W0

        % Autarky (different from value of defaut because of the haircut)
        twist = 1; % set to 0 for robots
        N = [ rho, (1-rho)*(1-twist*lambda);(1-alpha),alpha*(1-twist*lambda)];
        Vect = [u(ZD*delta)-delta+beta*twist*lambda*(1-rho)*W0; u(upinv(1/ZD))-upinv(1/ZD)/ZD+beta*twist*lambda*alpha*W0];
        A = ((eye(2) - beta*N)^-1)*Vect;
        Vuaut0 = A(1);
        Veaut0 = A(2);

        %value in default
        Vuaut = u(ZD*delta + Bbar)- delta                  + beta*(1-rho)*(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*rho*Vuaut0;
        Veaut = u(upinv(1/ZD))    -(upinv(1/ZD) - Bbar)/ZD + beta*alpha  *(twist*lambda*W0 + (1-lambda)*Veaut0) + beta*(1-alpha)*Vuaut0;

        % default in 2

        %a(D-1) = ((1-beta*rho)*Vuaut - u(c(D-1)) + delta - + beta*(1-rho)*W0)/(beta*(1-rho));
        aeb = Veaut-W0;
        a(D-1) = aeb;

        if D>2
            a(D-2) = p*(1-rho)*a(D-1)+c(D-1)-delta + p*rho*Bbar +tau;
                for k=(D-2):-1:2;
                    a(k-1) = p*a(k)+c(k)-delta +tau;
                end;
                a0 = p*a(1)+c(1)-delta +tau;
        else
            a0 = p*(1-rho)*a(1)+c(1)-delta +tau;

        end

        % 4) I solve for W0

        Vu(D) = Vuaut;

        for k=(D-1):-1:1;
            Vu(k) = u(c(k))-delta +beta*(1-rho)*a(k)+beta*(1-rho)*W0...
                +beta*rho*Vu(k+1);
        end;

        W0t = (u(upinv(1))-upinv(1) -p*a0 +beta*alpha*a0+beta*(1-alpha)*Vu(1))/(1-beta*alpha);
        dist = W0-W0t;
        W0 = W0 -0.1*dist;
        %dist = 0;
         end;

F = np0*a0 + np(1:(D-2))*(a(1:D-2)') + np(D-1)*(1-rho)*a(D-1) + np(D-1)*rho*Bbar;
tau2 = F*(1-p)/npartot;
Delta = tau-tau2;
tau=tau2;
end;

 COND = W0 - Veaut0;

tau = F*(1-p)/npartot;





pD = p;
aD0 = a0;
aD = a([1:D-1]);
W0D = W0;
VuD = Vu([1:D]);
cD=c;
%break

figure;
plot([aD0,aD]);
title('Assets in the economy with fund');


 % Welfare

clear p a0 a W0 vU c
p  =  pD;
a0 = aD0;
a = aD;
W0 = W0D;
Vu = VuD;
c = cD;

nex0 = ne*(1-lambda)*(1-alpha)*(rho^(D-1))/(lambda +(1-lambda)*(1-alpha)*rho^(D-1));% total productive excluded
nex01 = np0*(1-alpha)*rho^D; % countries just defaulting (being unproductive)

for k=1:D-1
    nex(k) = (1-alpha)*nex0*rho^(k-1);
end;


for k=D:1000
    nex(k) = (1-alpha)*(1-rho)/(2-alpha-rho)*(rho^(k-1));
end;


 
 for i =1:D-1;
     l0(i) = p*a0 + upinv(1)-a(i);
 end;   
 
 l00 = p*a0 + upinv(1)-a0 ;
 
 l0expar = p*a0 + upinv(1);
 
 Welf = np0*u(upinv(1)) - alpha*np0*l00...
     -(1-rho)*(np(1:D-1)*l0(1:D-1)')...
     -lambda*(alpha*nex0+(1-rho)*(nextot-nex0))*l0expar...
     + sum( np(1:D-1).*(u(c(1:D-1))-delta))...
    + nex0*(u(upinv(1/ZD))-upinv(1/ZD)/ZD)...
    + (nextot-nex0 - nex01)*(u(ZD*delta)-delta)...
    + nex01*(u(ZD*delta+Bbar)-delta);
 
 %check
 XX = np0...
     + sum( np(1:D-1))...
     + nex0...
     +(nextot-nex0)...
     -1;
 
    
     
WELFARE_fund = (1+Welf)/(1-beta);
%load welfare_market_haircut


%Welfm = -1.0000-2.5649e-05;

%Difference in welfare in consumption unit

dc = 1;
dW = 1;

while abs(dW)>10^-5  
    Welf_t = np0*u(upinv(1)*dc) - alpha*np0*l00...
     -(1-rho)*(np(1:D-1)*l0(1:D-1)')...
     -lambda*(alpha*nex0+(1-rho)*(nextot-nex0))*l0expar...
     + sum( np(1:D-1).*(u(c(1:D-1)*dc)-delta))...
    + nex0*(u(upinv(1/ZD)*dc)-upinv(1/ZD)/ZD)...
    + (nextot-nex0 - nex01)*(u(ZD*delta*dc)-delta)...
    + nex01*(u((ZD*delta+Bbar)*dc)-delta);

% Welf_t = np0*u(upinv(1)*dc) - alpha*np0*l00...
%      -(1-rho)*(np(1:D-1)*l0(1:D-1)')...
%      -nre*l0expar...
%      + sum( np(1:D-1).*(u(c(1:D-1)*dc)-delta))...
%      + nex0*(u(upinv(1/ZD)*dc)-upinv(1/ZD)/ZD)...
%      +(nextot-nex0)*(u(ZD*delta*dc)-delta);
 
 dW = Welf_t- Welfm;
 dc = dc -  0.1*dW;
 
 
end;

WELFARE_F = (1+Welf_t)/(1-beta);
dcf = (1-dc)*100;


% results

%targets (for D=2 only)
FGDP = F/WGDP; % size of the fund as a fraction of world GDP
r_int = 1/p;

disp(' ');

fprintf('Want to join the fund (must be >0)   %2.5f   \n',COND);
fprintf('Size of the fund in percent of GDP %2.1f percent  \n',FGDP*100);
fprintf('The annual world interest rate is %2.2f percent \n',(r_int-1)*100);

fprintf('Contribution to the fund (percent of average GDP)  %2.2f percent \n',tau/AGDP*100);
fprintf(' welfare cost  in consumption equivalent (in percent)  %2.2f percent \n', dcf);

fprintf('The percentage of countries defaulting  is %2.2f percent \n',nex01*100);
fprintf('Share of countries in the default state is %2.2f percent \n',nextot*100);
fprintf('The probability of default is %2.2f percent \n',Frac*100);

 
 
